summaryrefslogtreecommitdiffstats
path: root/jjb/fuel/fuel-deploy.sh
diff options
context:
space:
mode:
Diffstat (limited to 'jjb/fuel/fuel-deploy.sh')
-rwxr-xr-xjjb/fuel/fuel-deploy.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/jjb/fuel/fuel-deploy.sh b/jjb/fuel/fuel-deploy.sh
index ddaebc94a..18b2fd730 100755
--- a/jjb/fuel/fuel-deploy.sh
+++ b/jjb/fuel/fuel-deploy.sh
@@ -12,7 +12,7 @@ set -o pipefail
export TERM="vt220"
-if [[ "$BRANCH" != 'master' ]]; then
+if [[ "$BRANCH" =~ 'danube' ]]; then
# source the file so we get OPNFV vars
source latest.properties
@@ -21,11 +21,11 @@ if [[ "$BRANCH" != 'master' ]]; then
fi
# shellcheck disable=SC2153
-if [[ "${JOB_NAME}" =~ "merge" ]]; then
- # set simplest scenario for virtual deploys to run for merges
+if [[ "${JOB_NAME}" =~ 'verify' ]]; then
+ # set simplest scenario for virtual deploys to run for verify
DEPLOY_SCENARIO="os-nosdn-nofeature-ha"
-elif [[ "${BRANCH}" != 'master' ]]; then
- # for none-merge deployments
+elif [[ "${BRANCH}" =~ 'danube' ]]; then
+ # for Danube deployments (no artifact for current master or newer branches)
# checkout the commit that was used for building the downloaded artifact
# to make sure the ISO and deployment mechanism uses same versions
echo "Checking out ${OPNFV_GIT_SHA1}"